@@ -15,6 +15,8 @@
 """
 
 from zope.component import adapts
+adapts.__doc__ = "Declares the types of objects that a multi-adapter adapts."
+
 from zope.interface import implements, implementsOnly, classProvides
 
 from martian import baseclass
@@ -22,7 +24,8 @@ from martian.error import GrokError, GrokImportError
 from martian import ClassGrokker, InstanceGrokker, GlobalGrokker
 
 from grokcore.component.components import (
-    Adapter, GlobalUtility, MultiAdapter, Context)
+    Adapter, GlobalUtility, MultiAdapter, Context, Subscription,
+    MultiSubscription)
 
 from grokcore.component.directive import (
     context, description, direct, name, order, path, provides, title,
@@ -31,6 +34,10 @@ from grokcore.component.directive import (
 from grokcore.component.decorators import (
     subscribe, adapter, implementer, provider)
 
+from grokcore.component.subscription import (
+    querySubscriptions, queryMultiSubscriptions,
+    queryOrderedSubscriptions, queryOrderedMultiSubscriptions)
+
 # Import this module so that it's available as soon as you import the
 # 'grokcore.component' package.  Useful for tests and interpreter examples.
 import grokcore.component.testing
